@@ -9,8 +9,9 @@ import signal
 import socket
 import ssl
 import urllib.request
+from typing import Optional
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('utils')
 
 
 def get_module_and_method_from_action(action):
@@ -76,6 +77,40 @@ def get_plugin_class_by_name(plugin_name):
         return None
 
 
+def get_plugin_name_by_class(plugin) -> Optional[str]:
+    """Gets the common name of a plugin (e.g. "music.mpd" or "media.vlc") given its class. """
+
+    from platypush.plugins import Plugin
+
+    if isinstance(plugin, Plugin):
+        plugin = plugin.__class__
+
+    class_name = plugin.__name__
+    class_tokens = [
+        token.lower() for token in re.sub(r'([A-Z])', r' \1', class_name).split(' ')
+        if token.strip() and token != 'Plugin'
+    ]
+
+    return '.'.join(class_tokens)
+
+
+def get_backend_name_by_class(backend) -> Optional[str]:
+    """Gets the common name of a backend (e.g. "http" or "mqtt") given its class. """
+
+    from platypush.backend import Backend
+
+    if isinstance(backend, Backend):
+        backend = backend.__class__
+
+    class_name = backend.__name__
+    class_tokens = [
+        token.lower() for token in re.sub(r'([A-Z])', r' \1', class_name).split(' ')
+        if token.strip() and token != 'Backend'
+    ]
+
+    return '.'.join(class_tokens)
+
+
 def set_timeout(seconds, on_timeout):
     """
     Set a function to be called if timeout expires without being cleared.
@@ -290,6 +325,10 @@ def is_functional_hook(obj) -> bool:
     return callable(obj) and hasattr(obj, 'hook')
 
 
+def is_functional_cron(obj) -> bool:
+    return callable(obj) and hasattr(obj, 'cron') and hasattr(obj, 'cron_expression')
+
+
 def run(action, *args, **kwargs):
     from platypush.context import get_plugin
     (module_name, method_name) = get_module_and_method_from_action(action)
